@@ -33,7 +33,9 @@ mod read_memory_by_address;
 mod read_status_of_dtc;
 mod security_access;
 mod start_diagnostic_session;
-
+mod routine;
+mod message_transmission;
+mod ioctl_mgr;
 
 pub use clear_diagnostic_information::*;
 pub use ecu_reset::*;
@@ -45,6 +47,9 @@ pub use read_memory_by_address::*;
 pub use read_status_of_dtc::*;
 pub use security_access::*;
 pub use start_diagnostic_session::*;
+pub use routine::*;
+pub use message_transmission::*;
+pub use ioctl_mgr::*;
 
 /// KWP Command Service IDs.
 ///
@@ -73,9 +78,9 @@ pub enum KWP2000Command {
     ReadMemoryByAddress,
     /// Security access functions. See [security_access]
     SecurityAccess,
-    ///
+    /// Disables normal CAN message transmission from an ECU. See [enable_normal_message_transmission]
     DisableNormalMessageTransmission,
-    ///
+    /// Enables normal CAN message transmission from an ECU. See [disable_normal_message_transmission]
     EnableNormalMessageTransmission,
     ///
     DynamicallyDefineLocalIdentifier,
@@ -83,11 +88,11 @@ pub enum KWP2000Command {
     WriteDataByIdentifier,
     ///
     InputOutputControlByLocalIdentifier,
-    ///
+    /// Starts a ECU routine given a local identifier. See [routine]
     StartRoutineByLocalIdentifier,
-    ///
+    /// Stops a ECU routine given a local identifier. See [routine]
     StopRoutineByLocalIdentifier,
-    ///
+    /// requests results of an executed routine given a local identifier. See [routine]
     RequestRoutineResultsByLocalIdentifier,
     ///
     RequestDownload,
@@ -101,7 +106,8 @@ pub enum KWP2000Command {
     WriteDataByLocalIdentifier,
     ///
     WriteMemoryByAddress,
-    ///
+    /// Tester present message. [Kwp2000DiagnosticServer] will automatically send this,
+    /// so no need to manually create a message with this SID
     TesterPresent,
     ///
     ControlDTCSettings,
