@@ -4,7 +4,6 @@
 //! UDS (Typically any ECU produced after 2006 supports this)
 
 use std::{
-    intrinsics::transmute,
     sync::{
         atomic::{AtomicBool, Ordering},
         mpsc, Arc,
@@ -15,17 +14,17 @@ use std::{
 
 use crate::{BaseServerPayload, BaseServerSettings, DiagError, DiagServerResult, DiagnosticServer, ServerEvent, ServerEventHandler, channel::IsoTPChannel, channel::IsoTPSettings, dtc::DTCFormatType, helpers};
 
-use self::diagnostic_session_control::UDSSessionType;
-
 mod diagnostic_session_control;
 mod ecu_reset;
 mod read_dtc_information;
 mod security_access;
+mod clear_diagnostic_information;
 
 pub use diagnostic_session_control::*;
 pub use ecu_reset::*;
 pub use read_dtc_information::*;
 pub use security_access::*;
+pub use clear_diagnostic_information::*;
 
 /// UDS Command Service IDs
 #[allow(missing_docs)]
@@ -237,6 +236,10 @@ pub enum UDSError {
     IsoSAEReserved(u8),
 }
 
+fn lookup_uds_nrc(x: u8) -> String {
+    format!("{:?}", UDSError::from(x))
+}
+
 impl From<u8> for UDSError {
     fn from(p: u8) -> Self {
         match p {
@@ -455,6 +458,7 @@ impl UdsDiagnosticServer {
                             &mut server_channel,
                             0x78,
                             0x21,
+                            lookup_uds_nrc
                         ) {
                             // 0x78 - Response correctly received, response pending
                             Ok(res) => {
@@ -495,6 +499,7 @@ impl UdsDiagnosticServer {
                             &mut server_channel,
                             0x78, // UDSError::RequestCorrectlyReceivedResponsePending
                             0x21,
+                            lookup_uds_nrc
                         );
                         //event_handler.on_event(&res);
                         if tx_res.send(res).is_err() {
@@ -520,7 +525,7 @@ impl UdsDiagnosticServer {
                     };
 
                     if let Err(e) =
-                        helpers::perform_cmd(addr, &cmd, &settings, &mut server_channel, 0x78, 0x21)
+                        helpers::perform_cmd(addr, &cmd, &settings, &mut server_channel, 0x78, 0x21, lookup_uds_nrc)
                     {
                         event_handler.on_event(ServerEvent::TesterPresentError(e))
                     }
@@ -593,8 +598,8 @@ impl DiagnosticServer<UDSCommand> for UdsDiagnosticServer {
                 match self.exec_command(cmd.clone()) {
                     Ok(resp) => return Ok(resp),
                     Err(e) => {
-                        if let DiagError::ECUError(_) = e {
-                            return Err(e); // ECU Error. Sending again won't help.
+                        if let DiagError::ECUError{code, def} = e {
+                            return Err(DiagError::ECUError{code, def}); // ECU Error. Sending again won't help.
                         }
                         last_err = Some(e); // Other error. Sleep and then try again
                         if let Some(sleep_time) = self.repeat_interval.checked_sub(start.elapsed())
